if (!window.PluginUtil) {
    var PluginUtil = {
        register: function(namespace, pluginName, rawPlugin) {
            for (var methodName in rawPlugin) {
                if (!rawPlugin.hasOwnProperty(methodName) || (typeof rawPlugin[methodName] != 'function'))
                    continue;
                window[namespace] = window[namespace] || {};
                if (!window[namespace][pluginName]) {
                    window[namespace][pluginName] = {};
                }

                var pluginProxy = window[namespace][pluginName];
                pluginProxy[methodName] = (function(methodName) {
                    return function() {
                        var args = arguments;
                        if (window.plus && window.plus.isReady) {
                            rawPlugin[methodName].apply(window, args);
                        } else {
                            document.addEventListener("plusready",  function() {
                                rawPlugin[methodName].apply(window, args);
                            }, true);
                        }
                    }
                })(methodName);
            }
        }
    };
}


(function() {


    //插件名称
    var PLUGIN_NAME = "ContactPlugin";
    //定义JS插件
    var ContactPlugin = {

        /**
         * 选择联系人
         *
         * successCallback 成功回调
         * errorCallback 失败回调
         */
        selectContact : function (successCallback, errorCallback) {
            var success = typeof successCallback !== 'function' ? null : function(data) {
                successCallback(data);
            };
            var fail = typeof errorCallback !== 'function' ? null : function(args) {
                errorCallback(args);
            };
            var callbackId = window.plus.bridge.callbackId(success, fail);
            var args = [callbackId];
            return window.plus.bridge.exec(PLUGIN_NAME, "selectContact", args);
        },

        /**
         * 根据号码查找联系人姓名,异步方法
         * 如果查找不到，返回null
         *
         */
        getNameByNo : function (phoneNo, successCallback, errorCallback) {
            var success = typeof successCallback !== 'function' ? null : function(data) {
                successCallback(data);
            };
            var fail = typeof errorCallback !== 'function' ? null : function(args) {
                errorCallback(args);
            };
            var callbackId = window.plus.bridge.callbackId(success, fail);
            var args = [callbackId, phoneNo];
            return window.plus.bridge.exec(PLUGIN_NAME, "getNameByNo", args);
        },

        /**
         * 获取联系人总条数,异步方法
         *
         */
        getContactCount : function (successCallback, errorCallback) {
            var success = typeof successCallback !== 'function' ? null : function(data) {
                successCallback(data);
            };
            var fail = typeof errorCallback !== 'function' ? null : function(args) {
                errorCallback(args);
            };
            var callbackId = window.plus.bridge.callbackId(success, fail);
            var args = [callbackId];
            return window.plus.bridge.execSync(PLUGIN_NAME, "getContactCount", args);
        },

    };

    window.PluginUtil.register("muna", PLUGIN_NAME, ContactPlugin);
})();

