if (!window.PluginUtil) {
    var PluginUtil = {
        register: function(namespace, pluginName, rawPlugin) {
            for (var methodName in rawPlugin) {
                if (!rawPlugin.hasOwnProperty(methodName) || (typeof rawPlugin[methodName] != 'function'))
                    continue;
                window[namespace] = window[namespace] || {};
                if (!window[namespace][pluginName]) {
                    window[namespace][pluginName] = {};
                }

                var pluginProxy = window[namespace][pluginName];
                pluginProxy[methodName] = (function(methodName) {
                    return function() {
                        var args = arguments;
                        if (window.plus && window.plus.isReady) {
                            rawPlugin[methodName].apply(window, args);
                        } else {
                            document.addEventListener("plusready",  function() {
                                rawPlugin[methodName].apply(window, args);
                            }, true);
                        }
                    }
                })(methodName);
            }
        }
    };
}

(function() {
    //插件名称
    var PLUGIN_NAME = "CouponPlugin";
    //定义JS插件
    var CouponPlugin = {

         /**
          * 获取优惠券
          * paramMap 传入参数(json)      参数1必须, 2-16参数根据查询条件组合传入即可
          * 包含:
          *   1.type 调用查询优惠券类型 (1:确认订单 2: 确认支付 3:商品可抵扣 4:还款优惠券)
          *   2.merchantId 商户Id
          *   3.productId 商品Id
          *   4.installAmt 首付金额
          *   5.monthCount 期数
          *   6.oncePercent 首付比例
          *   7.orderAmt 订单金额
          *   8.orderType 订单类型 (1:普通订单,2:募集订单, 3:代购订单, 4:线下合作 ,5:线上合作 ,6:API对)
          *   9.productCategoryId 商品分类ID
          *   10.tranAmt 支付金额      (查询商品可抵扣优惠信息)
          *   11.awardNo 优惠券序列号
          *   12.debtDate 借据发生时间
          *   13.feeAmt 费用利息
          *   14.principalAmt 本金
          *   15.businessType 业务类型  D00 取现 T00消费
          * successCallback 成功回调
          * errorCallback 失败回调
          */
        selectCoupon : function (paramMap, successCallback, errorCallback) {
            var success = typeof successCallback !== 'function' ? null : function(data) {
                successCallback(data);
            };
            var fail = typeof errorCallback !== 'function' ? null : function(args) {
                errorCallback(args);
            };
            var callbackId = window.plus.bridge.callbackId(success, fail);
            var args = [callbackId,paramMap];
            return window.plus.bridge.exec(PLUGIN_NAME, "selectCoupon", args);
        }
    };
    //输出插件
    window.PluginUtil.register("muapp", PLUGIN_NAME, CouponPlugin);

})();