if (!window.PluginUtil) {
    var PluginUtil = {
        register: function(namespace, pluginName, rawPlugin) {
            for (var methodName in rawPlugin) {
                if (!rawPlugin.hasOwnProperty(methodName) || (typeof rawPlugin[methodName] != 'function'))
                    continue;
                window[namespace] = window[namespace] || {};
                if (!window[namespace][pluginName]) {
                    window[namespace][pluginName] = {};
                }

                var pluginProxy = window[namespace][pluginName];
                pluginProxy[methodName] = (function(methodName) {
                    return function() {
                        var args = arguments;
                        if (window.plus && window.plus.isReady) {
                            rawPlugin[methodName].apply(window, args);
                        } else {
                            document.addEventListener("plusready",  function() {
                                rawPlugin[methodName].apply(window, args);
                            }, true);
                        }
                    }
                })(methodName);
            }
        }
    };
}
(function() {

    //插件名称
    var PLUGIN_NAME = "IdScannerPlugin";
    //定义JS插件
    var IdScannerPlugin = {

        /**
         * 扫描身份证正面
         *
         * successCallback 成功回调
         * errorCallback 失败回调
         */
        startScanIdFront : function (successCallback, errorCallback) {
            var success = typeof successCallback !== 'function' ? null : function(data) {
                successCallback(data);
            };
            var fail = typeof errorCallback !== 'function' ? null : function(args) {
                errorCallback(args);
            };
            var callbackId = window.plus.bridge.callbackId(success, fail);
            var args = [callbackId];
            return window.plus.bridge.exec(PLUGIN_NAME, "startScanIdFront", args);
        },

        /**
         * 扫描身份证反面
         *
         * successCallback 成功回调
         * errorCallback 失败回调
         */
        startScanIdBack : function (successCallback, errorCallback) {
            var success = typeof successCallback !== 'function' ? null : function(data) {
                successCallback(data);
            };
            var fail = typeof errorCallback !== 'function' ? null : function(args) {
                errorCallback(args);
            };
            var callbackId = window.plus.bridge.callbackId(success, fail);
            var args = [callbackId];
            return window.plus.bridge.exec(PLUGIN_NAME, "startScanIdBack", args);
        },

        /**
         * 扫描银行卡
         *
         * successCallback 成功回调
         * errorCallback 失败回调
         */
        startScanBankCard : function (successCallback, errorCallback) {
            var success = typeof successCallback !== 'function' ? null : function(data) {
                successCallback(data);
            };
            var fail = typeof errorCallback !== 'function' ? null : function(args) {
                errorCallback(args);
            };
            var callbackId = window.plus.bridge.callbackId(success, fail);
            var args = [callbackId];
            return window.plus.bridge.exec(PLUGIN_NAME, "startScanBankCard", args);
        },

    };

    //输出插件
    window.PluginUtil.register("muna", PLUGIN_NAME, IdScannerPlugin);

})();