if (!window.PluginUtil) {
    var PluginUtil = {
        register: function(namespace, pluginName, rawPlugin) {
            for (var methodName in rawPlugin) {
                if (!rawPlugin.hasOwnProperty(methodName) || (typeof rawPlugin[methodName] != 'function'))
                    continue;
                window[namespace] = window[namespace] || {};
                if (!window[namespace][pluginName]) {
                    window[namespace][pluginName] = {};
                }

                var pluginProxy = window[namespace][pluginName];
                pluginProxy[methodName] = (function(methodName) {
                    return function() {
                        var args = arguments;
                        if (window.plus && window.plus.isReady) {
                            rawPlugin[methodName].apply(window, args);
                        } else {
                            document.addEventListener("plusready",  function() {
                                rawPlugin[methodName].apply(window, args);
                            }, true);
                        }
                    }
                })(methodName);
            }
        }
    };
}
(function() {
    //插件名称
    var PLUGIN_NAME = "UiKitPlugin";
    //定义JS插件
    var UiKitPlugin = {

        /**
         * 显示toast消息
         *
         * type int类型 0，普通类型； 1，带成功图标的toast； 2，带失败图标的toast
         * message String类型 toast消息内容
         */
        showToast : function (type, content) {
            var args = [type, content];
            return window.plus.bridge.exec(PLUGIN_NAME, "showToast", args);
        },

        /**
         * 显示对话框消息
         * message 消息组件，message的属性如下
         *    var message = {
         *                title:"测试标题1",
         *                content:"测试内容：丢啊大家靠ie亲尽快到倒萨大家哦i允id极爱拒绝加qiii快\n快快快快快上搜搜，；aolodm妈妈穿哦哦哦哦哦哦婆婆婆婆",
         *                positiveText:"确定的按钮",
         *                positiveListener:function() {
         *                },
         *                negativeText:"取消的按钮",
         *                negativeListener:function() {
         *                },
         *             }
         */
        showMessage: function(message) {

            var success = function(data) {
                if (typeof message.positiveListener == 'function') {
                    message.positiveListener();
                }
            }

            var fail = function(data) {
                if (data.errCode == 1) {
                    if (typeof message.negativeListener == 'function') {
                        message.negativeListener();
                    }
                } else {
                    if (typeof message.cancelListener == 'function') {
                        message.cancelListener();
                    }
                }
            }

            var callbackId = window.plus.bridge.callbackId(success, fail);

            var args = [callbackId, message];

            return window.plus.bridge.exec(PLUGIN_NAME, "showMessageBox", args);
        },

        /**
         * 关闭整个网页所在界面
         */
        webClose : function() {
            return window.plus.bridge.exec(PLUGIN_NAME, "webClose");
        },

        /**
         * 显示ActionSheet
         *
         * successCallback 成功回调 function(position)
         * cancelCallback 取消回调
         */
        showActionSheet : function (items, successCallback, cancelCallback) {
            var success = typeof successCallback !== 'function' ? null : function(data) {
                successCallback(data);
            };
            var fail = typeof cancelCallback !== 'function' ? null : function(args) {
                cancelCallback();
            };
            var callbackId = window.plus.bridge.callbackId(success, fail);
            var args = [callbackId, items];
            return window.plus.bridge.exec(PLUGIN_NAME, "showActionSheet", args);
        },

        /**
         * 显示等待框
         */
        showLoading : function() {
            return window.plus.bridge.exec(PLUGIN_NAME, "showLoading");
        },

        /**
         * 消除等待框
         */
        dismissLoading : function() {
            return window.plus.bridge.exec(PLUGIN_NAME, "dismissLoading");
        },

    };
    //输出插件
    window.PluginUtil.register("muna", PLUGIN_NAME, UiKitPlugin);

})();