if (!window.PluginUtil) {
    var PluginUtil = {
        register: function(namespace, pluginName, rawPlugin) {
            for (var methodName in rawPlugin) {
                if (!rawPlugin.hasOwnProperty(methodName) || (typeof rawPlugin[methodName] != 'function'))
                    continue;
                window[namespace] = window[namespace] || {};
                if (!window[namespace][pluginName]) {
                    window[namespace][pluginName] = {};
                }

                var pluginProxy = window[namespace][pluginName];
                pluginProxy[methodName] = (function(methodName) {
                    return function() {
                        var args = arguments;
                        if (window.plus && window.plus.isReady) {
                            rawPlugin[methodName].apply(window, args);
                        } else {
                            document.addEventListener("plusready",  function() {
                                rawPlugin[methodName].apply(window, args);
                            }, true);
                        }
                    }
                })(methodName);
            }
        }
    };
}

(function() {
    //插件名称
    var PLUGIN_NAME = "UtilsPlugin";
    //定义JS插件
    var UtilsPlugin = {
        /**
         * AES加密
         *
         * seed 加密因子
         * clearText 需要加密的明文
         */
        aesEncrypt : function (seed, clearText) {
            return window.plus.bridge.execSync(PLUGIN_NAME, "aesEncrypt", [seed, clearText]);
        },
        /**
         * AES解密
         * seed 解密因子
         * encryptText 需要解密的密文
         */
        aesDecrypt : function (seed, encryptText) {
            return window.plus.bridge.execSync(PLUGIN_NAME, "aesDecrypt", [seed, encryptText]);
        },
        /**
         * RSA加密，只支持公钥加密
         * publicKey 公钥
         * clearText 需要加密的明文
         */
        rsaEncrypt : function (publicKey, clearText) {
            return window.plus.bridge.execSync(PLUGIN_NAME, "rsaEncrypt", [publicKey, clearText]);
        },
        /**
         * RSA解密，只支持私钥解密
         * privateKey 私钥
         * encryptText 需要解密的密文
         */
        rsaDecrypt : function (privateKey, encryptText) {
            return window.plus.bridge.execSync(PLUGIN_NAME, "rsaDecrypt", [privateKey, encryptText]);
        }
    };
    //输出插件
    window.PluginUtil.register("muna", PLUGIN_NAME, UtilsPlugin);

})();