if (!window.PluginUtil) {
    var PluginUtil = {
        register: function(namespace, rawPlugin) {
            for (var methodName in rawPlugin) {
                if (!rawPlugin.hasOwnProperty(methodName) || (typeof rawPlugin[methodName] != 'function'))
                    continue;
                window[namespace] = window[namespace] || {};

                var pluginProxy = window[namespace];
                pluginProxy[methodName] = (function(methodName) {
                    return function() {
                        var args = arguments;
                        if (window.plus && window.plus.isReady) {
                            rawPlugin[methodName].apply(window, args);
                        } else {
                            document.addEventListener("plusready",  function() {
                                rawPlugin[methodName].apply(window, args);
                            }, true);
                        }
                    }
                })(methodName);
            }
        }
    };
}
(function() {

    //插件名称
    var PLUGIN_NAME = "MUJSBridge";

    //定义JS-SDK
    var MUJSBridge = {

        config : function (args) {
            if (!args)  {
                return;
            }

            var success = function() {
                MUJSBridge.isReady = true;
                if (typeof MUJSBridge.readyFunc == 'function') {
                    MUJSBridge.readyFunc();
                }
            };

            var fail = function(result) {
                MUJSBridge.isReady = true;
                MUJSBridge.errorResult = result;
                if (typeof MUJSBridge.errorFunc == 'function') {
                    MUJSBridge.errorFunc(result);
                }
            };

            var callbackId = window.plus.bridge.callbackId(success, fail);

            var transform = {
                appId:args.appId,
                apiList:args.apiList,
            }
            var args = [callbackId, transform];
            return window.plus.bridge.exec(PLUGIN_NAME, "config", args);
        },

        ready : function(func) {
            if (typeof func !== 'function')  {
                return;
            }

            if (MUJSBridge.isReady) {
                func();
            }
            MUJSBridge.readyFunc  = func;
        },

        error : function(func) {
            if (typeof func !== 'function')  {
                return;
            }

            if (MUJSBridge.isReady) {
                func(MUJSBridge.errorResult);
            }
            MUJSBridge.errorFunc  = func;
        },

        callNativeMethod: function (methodName, args) {
            if (!methodName)  {
                return;
            }
            if (!args) {
                args = {};
            }
            var success = typeof args.success !== 'function' ? null : function(result) {
                args.success(result);
            };
            var fail = typeof args.fail !== 'function' ? null : function(error) {
                args.fail(error);
            };

            var callbackId = window.plus.bridge.callbackId(success, fail);
            var transmission = [callbackId, args];
            return window.plus.bridge.exec(PLUGIN_NAME, methodName, transmission);
        },

        chooseImage : function(args) {
            return MUJSBridge.callNativeMethod("chooseImage", args);
        },

        getLocation:function(args) {
            return MUJSBridge.callNativeMethod("getLocation", args);
        },

        scanQRCode : function(args) {
            return MUJSBridge.callNativeMethod("scanQRCode", args);
        },

        choosePhoneContact : function(args) {
            return MUJSBridge.callNativeMethod("choosePhoneContact", args);
        },

        findPhoneContactName : function(args) {
            return MUJSBridge.callNativeMethod("findPhoneContactName", args);
        },

        share : function(args) {
            return MUJSBridge.callNativeMethod("share", args);
        },

        getNetworkType : function(args) {
            return MUJSBridge.callNativeMethod("getNetworkType", args);
        },

        setBackListener : function(args) {
            var success = function(result) {
                if (result.event == 'click' && typeof args.click == 'function') {
                    args.click();
                } else if (typeof args.success == 'function'){
                    args.success();
                }
            };
            return MUJSBridge.callNativeMethod("setBackListener",{success:success, fail:args.fail} );
        },

        setOptionButton : function(args) {

            var success = function(result) {
                if (result.event == 'click' && typeof args.click == 'function') {
                    args.click(result.index);
                } else if (typeof args.success == 'function'){
                    args.success();
                }
            };

            var option = {
                items:args.items,
                option:args.option,
                success:success,
                fail:args.fail,
            };
            return MUJSBridge.callNativeMethod("setOptionButton", option);
        },

        setTitle : function(args) {
            return MUJSBridge.callNativeMethod("setTitle", args);
        },

        closeWeb : function(args) {
            return MUJSBridge.callNativeMethod("closeWeb");
        },

    };

    window.PluginUtil.register("MUJSBridge", MUJSBridge);

})();